@@ -26,8 +26,8 @@ class Grid(LocationGroup):
         # use a cross product to calculate a new y vector axis relative orthogonal to x and z, then project the given
         # y vector on to it to get a new orthogonal y axis with the proper length
         y_ortho = y.project(z.cross(x))
-        x_spacing = x.magnitude / columns
-        y_spacing = y_ortho.magnitude / rows
+        x_spacing = x.magnitude / (columns - 1) if columns > 1 else 0.0
+        y_spacing = y_ortho.magnitude / (rows - 1) if rows > 1 else 0.0
 
         # location = Location.from_xy(bottom_left.position, x, y_ortho)
         spacing = Cartesian(x_spacing, y_spacing)
